from flask import Flask, request, jsonify
from flask_cors import CORS
import configparser
from helper import storecmd, getcmd, updatestatus, getstatus, getalldata, updatelocation, getdbtime, datelookup
import datetime

app = Flask(__name__)
CORS(app)


def verifyapikey(requestapikey):
    if requestapikey == apiKey:
        return True
    return False


@app.route('/cmd', methods=['POST', 'GET'])
def command():
    if verifyapikey(request.values.get('apikey')):
        if request.method == 'POST':
            storecmd(request.values.get('id'), datetime.datetime.now(), request.values.get('response'))
            return jsonify(response='success'), 200
        else:
            results = getcmd(request.values.get('id'))
            x = 0
            response = {}
            for i in results:
                response[x] = {'date': i[0], 'command': i[1]}
                x = x + 1
            return response, 200
    return jsonify(response='invalid api key'), 401


@app.route('/status', methods=['POST', 'GET'])
def status():
    if verifyapikey(request.values.get('apikey')):
        if request.method == 'POST':
            updatestatus(request.values.get('id'), datetime.datetime.now(), request.values.get('key'),
                         request.values.get('value'))
            return jsonify(response='success'), 200
        else:
            result = getstatus(request.values.get('id'), request.values.get('key'))
            return jsonify(response=result[0]), 200
    return jsonify(response='invalid api key'), 401


@app.route('/gettime', methods=['POST'])
def gettime():
    if verifyapikey(request.values.get('apikey')):
        result = getdbtime(request.values.get('id'), request.values.get('key'))
        return jsonify(response=str(result[0])), 200
    return jsonify(response='invalid api key'), 401


@app.route('/fullstatus', methods=['POST'])
def fullstatus():
    if verifyapikey(request.values.get('apikey')):
        result = getalldata(request.values.get('id'))
        return {'switch_name': result[1],
                'switch_status': result[3],
                'astral_status': result[4],
                'conn_status': result[5],
                'last_updated': result[2],
                'on_time': str(result[6]),
                'off_time': str(result[7]),
                'loc_name': result[8],
                'loc_region': result[9],
                'loc_lat': result[10],
                'loc_lon': result[11],
                'loc_timezone': result[12],
                'apikey': result[13]
                }, 200
    return jsonify(response='invalid api key'), 401


@app.route('/updatelocation', methods=['POST'])
def updateloc():
    if verifyapikey(request.values.get('apikey')):
        updatelocation(request.values.get('id'), datetime.datetime.now(), request.values.get('loc_name'),
                       request.values.get('loc_region'), request.values.get('loc_lat'), request.values.get('loc_lon'))
        return jsonify(response='success'), 200
    return jsonify(response='invalid api key'), 401


@app.route('/datelookup', methods=['POST'])
def lookupdate():
    if verifyapikey(request.values.get('apikey')):
        result = datelookup(request.values.get('id'),
                            request.values.get('day'), request.values.get('month'), request.values.get('year'))
        return jsonify(response=result), 200
    return jsonify(response='invalid api key'), 401


if __name__ == '__main__':
    config = configparser.ConfigParser()
    config.read('config.ini')
    apiKey = config['setup']['apikey']
    app.run(host='0.0.0.0')
