import mysql.connector
import configparser
import astral
import astral.sun
import datetime

config = configparser.ConfigParser()
config.read('config.ini')
host = config['database']['host']
user = config['database']['user']
password = config['database']['password']
db = config['database']['db']


def storecmd(device_id, date_time, command):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute("""INSERT INTO commands(device_id,date_time,command) VALUES(%s,%s,%s)""", (device_id, date_time, command))
    dwh.commit()
    c.close()


def getcmd(device_id):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute("""SELECT date_time, command FROM commands WHERE device_id = %s ORDER BY date_time DESC LIMIT 10 """,
              (device_id,))
    result = c.fetchmany(10)
    c.close()
    return result


def updatestatus(device_id, date_time, key, value):
    if key in ['device_id', 'name', 'last_updated', 'switch_status', 'astral_status', 'conn_status', 'on_time',
               'off_time', 'loc_name', 'loc_region', 'loc_lat', 'loc_lon', 'loc_timezone', 'apikey']:
        dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
        c = dwh.cursor()
        c.execute("""UPDATE status SET last_updated = %s, {} = %s WHERE device_id = %s""".format(key),
                  (date_time, value, device_id))
        dwh.commit()
        c.close()


def getstatus(device_id, key):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute("""SELECT {} FROM status WHERE device_id = %s""".format(key), ([device_id]))
    result = c.fetchone()
    c.close()
    return result


def getalldata(device_id):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute("""SELECT * FROM status WHERE device_id = %s""", ([device_id]))
    result = c.fetchone()
    c.close()
    return result


def updatelocation(device_id, date_time, loc_name, loc_region, loc_lat, loc_lon):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute(
        """UPDATE status SET last_updated = %s, loc_name = %s, loc_region = %s, loc_lat = %s, loc_lon = %s WHERE device_id = %s""",
        (date_time, loc_name, loc_region, loc_lat, loc_lon, device_id))
    dwh.commit()
    c.close()


def getdbtime(device_id, key):
    if key in ['device_id', 'name', 'last_updated', 'switch_status', 'astral_status', 'conn_status', 'on_time',
               'off_time', 'loc_name', 'loc_region', 'loc_lat', 'loc_lon', 'loc_timezone', 'apikey']:
        dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
        c = dwh.cursor()
        c.execute("""SELECT {} FROM status WHERE device_id = %s""".format(key), ([device_id]))
        result = c.fetchone()
        c.close()
        return result


def datelookup(device_id, day, month, year):
    dwh = mysql.connector.connect(host=host,user=user,password=password,database=db)
    c = dwh.cursor()
    c.execute("""SELECT loc_name, loc_region, loc_lat, loc_lon, loc_timezone FROM status WHERE device_id = %s""",
              (device_id,))
    result = c.fetchone()
    c.close()
    l = astral.LocationInfo(name=result[0], region=result[1], latitude=result[2], longitude=result[3],
                            timezone=result[4])
    triggerontime = astral.sun.sunset(observer=l.observer, date=datetime.date(day, month, year))
    return triggerontime
